@@ -46,7 +46,7 @@ class DXAPIError(DXError):
         output = self.msg + ", code " + str(self.code)
         if self.name != self.__class__.__name__:
             output = self.name + ": " + output
-        if self.details is not None:
+        if self.details:
             output += "\nDetails: " + json.dumps(self.details, indent=4)
         return output
 
